{% load i18n %}

<h4 class="title">{% trans "Invite" %}</h4>
<span class="alert alert-info">{% trans "Please add an email below. The user will receive an email with instructions." %}</span>

<form id="invite-form" method="POST" action="{% url 'invitations:send-invite' %}">
  {% csrf_token %}
  <div class="form-group">
      <input type="text" name="email" id="id_email" value="{{ form.email.value }}" class="form-control validate-email" placeholder="{% trans 'Email' %}">
  </div>
  <div class="form-group">
    {% for error in form.email.errors %}
      <div class="alert alert-danger">{{ error }}</div>
    {% endfor %}
    {{ success_message }}
  </div>
  <input type="submit" value="Submit" class="btn btn-primary generic-ajax-submit">
</form>
